import { LabIcon } from '@jupyterlab/ui-components';

// icon svg import statements
import party from '../style/icons/party.svg';

export const partyIcon = new LabIcon({
  name: '@mljar/party-icon',
  svgstr: party
});
