@import url('base.css');

.mercury-panel {
    padding: 0px;
  }

.hide-element {
  display: none;
}

.mercury-main-panel {
  display: inline-flex;
  width: 100%;
  height: 100%;
}

.mercury-left-panel {
  background-color: rgb(248, 249, 250);
  width: 30%;
  padding-left: 10px;
  overflow-x: hidden;
  overflow-y: auto;
  box-shadow: inset -1px 0 0 rgba(0, 0, 0, 0.1);
  border-left: 1px solid #eeeeee;
}

.mercury-right-panel {
  width: 70%;
  overflow-y: auto;
}
